summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmerrordialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmerrordialog.h')
-rw-r--r--kpovmodeler/pmerrordialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmerrordialog.h b/kpovmodeler/pmerrordialog.h
index 8310b3ad..06982e69 100644
--- a/kpovmodeler/pmerrordialog.h
+++ b/kpovmodeler/pmerrordialog.h
@@ -45,7 +45,7 @@ class PMErrorDialog : public KDialogBase
TQ_OBJECT
public:
/**
* Creates a modal PMErrorDialog with tqparent and name.
*
* messages is the message list. If the list contains a message of type
* FatalError, the 'Proceed" button will not be shown.
@@ -54,7 +54,7 @@ public:
* should be continued.
*/
PMErrorDialog( const PMMessageList& messages, int errorFlags,
- TQWidget* tqparent = 0, const char* name = 0 );
+ TQWidget* parent = 0, const char* name = 0 );
static void saveConfig( KConfig* cfg );
static void restoreConfig( KConfig* cfg );
@@ -45,7 +45,7 @@ class PMErrorDialog : public KDialogBase
public:
/**
- * Creates a modal PMErrorDialog with tqparent and name.
+ * Creates a modal PMErrorDialog with parent and name.
*
* messages is the message list. If the list contains a message of type